from unittest import skip
import frontmatter
import click
import os
import glob
import shutil
import fnmatch


@click.command()
@click.option("--input-dir", "-i", required=True)
@click.option('--output-dir','-o', required=True)
@click.option('--ignore', default=None, required=False, multiple=True)
@click.option('--dry-run/--no-dry-run', default=False)
def main(input_dir: str, output_dir, ignore=None, dry_run=False):

    public_files = []
    
    for file in glob.glob(os.path.join(input_dir,"**","*.md")):

        
        if ignore is not None:
            skip_file = False

            for pattern in ignore:
                if fnmatch.fnmatch(file, pattern):
                    skip_file = True
        
            if skip_file: 
                continue

        with open(file) as f:
            data = frontmatter.load(f)

        if data.get('public'):
            print(f"public file {file}")
            public_files.append(file)

            
    for file in public_files:
        path = file[len(input_dir):]
        out_path = os.path.join(os.path.abspath(output_dir), path)

        if not os.path.exists(os.path.dirname(out_path)):
            print(f"mkdir {os.path.dirname(out_path)}")

            if not dry_run:
                os.makedirs(os.path.dirname(out_path), exist_ok=True)

        print(f"{file} => {out_path}")
        if not dry_run:
            shutil.copy(file, out_path)


if __name__ == "__main__":
    main()